2023-10-19 Version: 1.2.0
- Generated python2 2017-12-14 for BssOpenApi.

2023-09-04 Version: 1.1.0
- Generated python2 2017-12-14 for BssOpenApi.

2023-05-19 Version: 1.0.12
- DescribeInstanceAmortizedCostByAmortizationPeriodDate

2023-03-07 Version: 1.0.11
- QuerySavingsPlansInstance api add status query param. 


2023-02-13 Version: 1.0.10
- SubscribeBillToOSS add param: RowLimitPerFile. 

2023-02-07 Version: 1.0.9
- Add other language.

2022-06-28 Version: 1.0.8
- Update QuerySavingsPlansDeductLog add field OwnerId.

2022-05-19 Version: 1.0.7
- Update SubscribeBillToOSS and QueryBillToOSSSubscription to support BucketPath.

2021-06-25 Version: 1.0.6
- AMP Version Change.

2021-06-15 Version: 1.0.5
- AMP Version Change.

2021-04-28 Version: 1.0.4
- AMP Version Change.

2021-03-26 Version: 1.0.3
- AMP Version Change.

2021-03-23 Version: 1.0.2
- Generated python2 2017-12-14 for BssOpenApi.

2021-03-19 Version: 1.0.1
- AMP Version Change.

2021-03-04 Version: 1.0.0
- AMP Version Change.

